import * as React from "react";
import * as TooltipPrimitive from "@radix-ui/react-tooltip";
import { cva, type VariantProps } from "class-variance-authority";
import { cn } from "../../lib/utils";


const tooltipVariants = cva(
  "",
  {
    variants:{
      variant:{
        top:"top",
        right:"right",
        bottom:"bottom",
        left:"left"
      }
    }
  }
)

type TooltipProviderProps = {
  trigger: React.ReactNode;
  content: Record<string, React.ReactNode>;
};

const TooltipProvider: React.FC<TooltipProviderProps & VariantProps<typeof tooltipVariants>> = ({ trigger, content, variant }) => {
  const side = variant && tooltipVariants({ variant }) as "top" | "right" | "bottom" | "left";

  return (
    <TooltipPrimitive.Provider>
      <Tooltip>
        <TooltipTrigger>{trigger}</TooltipTrigger>
        <TooltipContent side={side || "bottom"}>
          {Object.values(content).map((value, index) => (
            <p key={index}>{value}</p>
          ))}
        </TooltipContent>
      </Tooltip>
    </TooltipPrimitive.Provider>
  );
};

const Tooltip = TooltipPrimitive.Root;

const TooltipTrigger = TooltipPrimitive.Trigger;

const TooltipContent = React.forwardRef<
  React.ElementRef<typeof TooltipPrimitive.Content>,
  React.ComponentPropsWithoutRef<typeof TooltipPrimitive.Content>
>(({ className, sideOffset = 4, ...props }, ref) => (
  <TooltipPrimitive.Content
    ref={ref}
    sideOffset={sideOffset}
    className={cn(
      "z-50 overflow-hidden rounded-md bg-primary/90 px-3 py-1.5 text-xs text-primary-foreground animate-in fade-in-0 zoom-in-95 data-[state=closed]:animate-out data-[state=closed]:fade-out-0 data-[state=closed]:zoom-out-95 data-[side=bottom]:slide-in-from-top-2 data-[side=left]:slide-in-from-right-2 data-[side=right]:slide-in-from-left-2 data-[side=top]:slide-in-from-bottom-2",
      className
    )}
    {...props}
  />
));
TooltipContent.displayName = TooltipPrimitive.Content.displayName;

export { TooltipProvider, Tooltip, TooltipTrigger, TooltipContent };
